@@ -2,10 +2,12 @@ package Genealogy::ObituaryDailyTimes;
 
 use warnings;
 use strict;
+
 use Carp;
 use File::Spec;
 use Module::Info;
 use Genealogy::ObituaryDailyTimes::obituaries;
+use Params::Get;
 use Scalar::Util;
 
 use constant URLS => {
@@ -20,11 +22,11 @@ Genealogy::ObituaryDailyTimes - Lookup an entry in the Obituary Daily Times
 
 =head1 VERSION
 
-Version 0.14
+Version 0.15
 
 =cut
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 =head1 SYNOPSIS
 
@@ -38,13 +40,17 @@ our $VERSION = '0.14';
 
 Creates a Genealogy::ObituaryDailyTimes object.
 
+    my $obits = Genealogy::ObituaryDailyTimes->new();
+
 Accepts the following optional arguments:
 
 =over 4
 
+=item * C<cache> - Passed to L<Database::Abstraction>
+
 =item * C<directory> - The directory containing the file obituaries.sql
 
-=item * C<logger> - An object to send log messages to
+=item * C<logger> - Passed to L<Database::Abstraction>
 
 =back
 
@@ -75,6 +81,7 @@ sub new {
 		$directory =~ s/\.pm$//;
 		$args{'directory'} = File::Spec->catfile($directory, 'data');
 	}
+
 	if(!-d $directory) {
 		Carp::carp(__PACKAGE__, ": $directory is not a directory");
 		return;
@@ -89,6 +96,13 @@ sub new {
 
 =head2 search
 
+Searches the database.
+
+    # Returns an array of hashrefs
+    my @smiths = $obits->search(last => 'Smith');	# You must at least define the last name to search for
+
+    print $smiths[0]->{'first'}, "\n";
+
 Supports two return modes:
 
 =over 4
@@ -99,23 +113,17 @@ Returns an array of hash references.
 
 =item * C<Scalar context>
 
-Returns a single hash reference.
+Returns a single hash reference,
+or C<undef> if there is no match.
 
 =back
 
-    my $obits = Genealogy::ObituaryDailyTimes->new();
-
-    # Returns an array of hashrefs
-    my @smiths = $obits->search(last => 'Smith');	# You must at least define the last name to search for
-
-    print $smiths[0]->{'first'}, "\n";
-
 =cut
 
 sub search
 {
 	my $self = shift;
-	my $params = $self->_get_params('last', @_);
+	my $params = Params::Get::get_params('last', @_);
 
 	if(!defined($params->{'last'})) {
 		Carp::carp("Value for 'last' is mandatory");
@@ -163,47 +171,17 @@ sub _create_url {
 		return URLS->{'F'} . $page;
 	}
 	if($source eq 'L') {
-		my $newspaper = $obit->{'newspaper'} || Carp::croak(__PACKAGE__, ": undefined newspaper.  Newspaper much be given when source type is 'L'");
-		return $newspaper;
+		if($obit->{'newspaper'} =~ /^https?:\/\//) {
+			return $obit->{'newspaper'};
+		}
+		if($obit->{'page'} =~ /^https?:\/\//) {
+			return $obit->{'page'};
+		}
+		Carp::croak(__PACKAGE__, ": undefined newspaper.  Newspaper much be given when source type is 'L'");
 	}
 	Carp::croak(__PACKAGE__, ": Invalid source, '$source'. Valid sources are 'M', 'F' and 'L'");
 }
 
-# Helper routine to parse the arguments given to a function,
-# Processes arguments passed to methods and ensures they are in a usable format,
-#	allowing the caller to call the function in anyway that they want
-#	e.g. foo('bar'), foo(arg => 'bar'), foo({ arg => 'bar' }) all mean the same
-#	when called _get_params('arg', @_);
-sub _get_params
-{
-	shift;  # Discard the first argument (typically $self)
-	my $default = shift;
-
-	# Directly return hash reference if the first parameter is a hash reference
-	return $_[0] if(ref $_[0] eq 'HASH');
-
-	my %rc;
-	my $num_args = scalar @_;
-
-	# Populate %rc based on the number and type of arguments
-	if(($num_args == 1) && (defined $default)) {
-		# %rc = ($default => shift);
-		return { $default => shift };
-	} elsif($num_args == 1) {
-		Carp::croak('Usage: ', __PACKAGE__, '->', (caller(1))[3], '()');
-	} elsif(($num_args == 0) && (defined($default))) {
-		Carp::croak('Usage: ', __PACKAGE__, '->', (caller(1))[3], "($default => \$val)");
-	} elsif(($num_args % 2) == 0) {
-		%rc = @_;
-	} elsif($num_args == 0) {
-		return;
-	} else {
-		Carp::croak('Usage: ', __PACKAGE__, '->', (caller(1))[3], '()');
-	}
-
-	return \%rc;
-}
-
 =head1 AUTHOR
 
 Nigel Horne, C<< <njh at bandsman.co.uk> >>
@@ -211,14 +189,35 @@ Nigel Horne, C<< <njh at bandsman.co.uk> >>
 =head1 BUGS
 
 Ancestry has removed the archives.
-The first 17 pages are on Wayback machine, but the rest is lost.
+The first 18 pages are on Wayback machine, but the rest is lost.
 
 =head1 SEE ALSO
 
-The Obituary Daily Times, L<https://sites.rootsweb.com/~obituary/>,
-Archived Rootsweb data, L<https://wayback.archive-it.org/20669/20231102044925/https://mlarchives.rootsweb.com/listindexes/emails?listname=gen-obit>,
-Recent data L<https://www.freelists.org/list/obitdailytimes>,
-Older data L<https://obituaries.rootsweb.com/obits/searchObits>.
+L<Database::Abstraction>
+
+=over 4
+
+=item * The Obituary Daily Times
+
+L<https://sites.rootsweb.com/~obituary/>
+
+=item * Archived Rootsweb data
+
+L<https://wayback.archive-it.org/20669/20231102044925/https://mlarchives.rootsweb.com/listindexes/emails?listname=gen-obit>
+
+=item * Funeral Notices
+
+L<https://www.funeral-notices.co.uk>
+
+=item * Recent data
+
+L<https://www.freelists.org/list/obitdailytimes>
+
+=item * Older data
+
+L<https://obituaries.rootsweb.com/obits/searchObits>
+
+=back
 
 =head1 SUPPORT
 
